@@ -1,8 +1,8 @@
 from .cli import cli  # noqa:F401
-from .alb import *  # noqa:F403,F401
 from .awslogs import *  # noqa:F403,F401
 from .cluster import *  # noqa:F403,F401
 from .elb import *  # noqa:F403,F401
+from .elbv2 import *  # noqa:F403,F401
 from .invoked_task import *  # noqa:F403,F401
 from .service import *  # noqa:F403,F401
 from .task import *  # noqa:F403,F401
