@@ -4,20 +4,25 @@ import os
 
 from .abstract import ClickModelAdapter, ClickBaseModelAdapter, ClickSecretsAdapter
 from .commands import (
+    ClickDisableHelperTaskMixin,
+    ClickDisableStandaloneTaskMixin,
+    ClickEnableHelperTaskMixin,
+    ClickEnableStandaloneTaskMixin,
+    ClickHelperTaskInfoCommandMixin,
+    ClickListHelperTaskLogsMixin,
+    ClickListHelperTasksCommandMixin,
+    ClickListRunningTasksCommandMixin,
+    ClickListServiceRelatedTasksCommandMixin,
+    ClickListStandaloneTaskLogsMixin,
     ClickRestartServiceCommandMixin,
+    ClickRunHelperTaskCommandMixin,
+    ClickRunStandaloneTaskCommandMixin,
     ClickScaleInstancesCommandMixin,
     ClickScaleServiceCommandMixin,
-    ClickUpdateServiceRelatedTasksCommandMixin,
-    ClickListHelperTasksCommandMixin,
-    ClickHelperTaskInfoCommandMixin,
-    ClickRunHelperTaskCommandMixin,
     ClickTailHelperTaskLogsMixin,
-    ClickListHelperTaskLogsMixin,
-    ClickRunStandaloneTaskCommandMixin,
     ClickTailStandaloneTaskLogsMixin,
-    ClickListRunningTasksCommandMixin,
-    ClickListStandaloneTaskLogsMixin,
     ClickUpdateHelperTasksCommandMixin,
+    ClickUpdateServiceRelatedTasksCommandMixin,
 )
 from deployfish.config import get_config
 from deployfish.exceptions import RenderException, ConfigProcessingFailed
@@ -77,6 +82,7 @@ class ClickServiceAdapter(
     ClickListRunningTasksCommandMixin,
     ClickScaleServiceCommandMixin,
     ClickRestartServiceCommandMixin,
+    ClickListServiceRelatedTasksCommandMixin,
     ClickUpdateServiceRelatedTasksCommandMixin,
     ClickModelAdapter
 ):
@@ -107,13 +113,22 @@ class ClickServiceAdapter(
     update_extra_help = """
 NOTES:
 
-  * All this command does is update your Services' configuration in AWS.  It does not manage your containers!  The AWS ECS service itself does the rolling deploy and deployfish simply reports on the status.
+  * All this command does is update your Services' configuration in AWS.  It does not manage
+    your containers!  The AWS ECS service itself does the rolling deploy and deployfish simply
+    reports on the status.
 
-  * We wait for 15 minutes for the Service to become stable after applying our updates to it.  A Service is stable when it sees that the Service has the correct number of running tasks, that those tasks are running the desired task definition, and that those tasks have passed their health checks. If it takes longer than 15 minutes for the service to be stable, deployfish will say the deploy timed out.  We do this because sometimes the deployment really is broken and we don't want our deployment pipelines in CodePipeline to run for hours waiting.
+  * We wait for 15 minutes for the Service to become stable after applying our updates to it.
+    A Service is stable when it sees that the Service has the correct number of running tasks,
+    that those tasks are running the desired task definition, and that those tasks have passed
+    their health checks. If it takes longer than 15 minutes for the service to be stable,
+    deployfish will say the deploy timed out.  We do this because sometimes the deployment
+    really is broken and we don't want our deployment pipelines in CodePipeline to run for hours
+    waiting.
 
   THE DEPLOYMENT IS STILL RUNNING IN AWS. Go to the AWS ECS Console to see status.
 
-  * If you want deployfish to wait more than 15 minutes, set the environment variable DEPLOYFISH_SERVICE_UPDATE_TIMEOUT to a longer value, in minutes.
+  * If you want deployfish to wait more than 15 minutes, set the environment variable
+    DEPLOYFISH_SERVICE_UPDATE_TIMEOUT  to a longer value, in minutes.
 
     export DEPLOYFISH_SERVICE_UPDATE_TIMEOUT=30
 """
@@ -164,11 +179,13 @@ class ClickServiceSecretsAdapter(
 
 class ClickServiceTasksAdapter(
     ServiceDereferenceMixin,
-    ClickListHelperTasksCommandMixin,
+    ClickDisableHelperTaskMixin,
+    ClickEnableHelperTaskMixin,
     ClickHelperTaskInfoCommandMixin,
+    ClickListHelperTaskLogsMixin,
+    ClickListHelperTasksCommandMixin,
     ClickRunHelperTaskCommandMixin,
     ClickTailHelperTaskLogsMixin,
-    ClickListHelperTaskLogsMixin,
     ClickUpdateHelperTasksCommandMixin,
     ClickBaseModelAdapter
 ):
@@ -178,6 +195,7 @@ class ClickServiceTasksAdapter(
     list_helper_tasks_ordering = 'Command Name'
     list_helper_tasks_result_columns = {
         'Command Name': 'command',
+        'Disabled?': 'schedule_disabled',
         'Revision': 'family_revision',
         'Version': 'version',
         'Launch Type': 'launchType',
@@ -189,21 +207,26 @@ class ClickStandaloneTaskAdapter(
     ClickRunStandaloneTaskCommandMixin,
     ClickTailStandaloneTaskLogsMixin,
     ClickListStandaloneTaskLogsMixin,
+    ClickDisableStandaloneTaskMixin,
+    ClickEnableStandaloneTaskMixin,
     ClickModelAdapter
 ):
 
     model = StandaloneTask
 
+    info_includes = ['secrets']
     list_ordering = 'Name'
     list_result_columns = {
         'Name': 'name',
+        'Disabled?': 'schedule_disabled',
         'Service': {'key': 'serviceName', 'default': ''},
         'Cluster': 'cluster__name',
         'Launch Type': 'launchType',
-        'Revision': 'family_revision',
+        'Revision': 'revision',
         'Version': 'version',
         'Schedule': 'schedule_expression'
     }
+    update_template = 'standalonetask--detail:short.tpl'
 
 
 class ClickStandaloneTaskSecretsAdapter(ClickSecretsAdapter):
