@@ -1,5 +1,4 @@
 from .abstract import *  # noqa:F403,F401
-from .alb import *  # noqa:F403,F401
 from .appscaling import *  # noqa:F403,F401
 from .cloudwatch import *    # noqa:F403,F401
 from .cloudwatchlogs import *    # noqa:F403,F401
@@ -7,6 +6,7 @@ from .ec2 import *    # noqa:F403,F401
 from .ecs import *    # noqa:F403,F401
 from .efs import *    # noqa:F403,F401
 from .elb import *    # noqa:F403,F401
+from .elbv2 import *  # noqa:F403,F401
 from .events import *    # noqa:F403,F401
 from .secrets import *    # noqa:F403,F401
 from .service_discovery import *   # noqa:F403,F401
