@@ -8,15 +8,39 @@ from deployfish.core.ssh import DockerMixin, SSHMixin
 from deployfish.core.utils import is_fnmatch_filter
 
 from .abstract import Manager, Model, LazyAttributeMixin
-from .alb import TargetGroup
 from .ec2 import Instance, AutoscalingGroup
 from .efs import EFSFileSystem
 from .elb import ClassicLoadBalancer
+from .elbv2 import TargetGroup
 from .events import EventScheduleRule
 from .mixins import TaskDefinitionFARGATEMixin, TagsMixin
 from .secrets import SecretsMixin, Secret
 from .appscaling import ScalableTarget
 from .service_discovery import ServiceDiscoveryService
+from .vpc import Subnet, SecurityGroup
+
+
+# ----------------------------------------
+# Mixins
+# ----------------------------------------
+
+class VPCConfigurationMixin:
+
+    @property
+    def vpc_configuration(self):
+        if 'vpc_configuration' not in self.cache:
+            if 'networkConfiguration' in self.data:
+                raw = self.data['networkConfiguration']['awsvpcConfiguration']
+                data = {}
+                data['subnets'] = [Subnet.objects.get(subnet_id) for subnet_id in raw['subnets']]
+                data['security_groups'] = [SecurityGroup.objects.get(sg_id) for sg_id in raw['securityGroups']]
+                data['allow_public_ip'] = raw.get('allowPublicIp', False)
+                data['vpc'] = data['subnets'][0].vpc
+                self.cache['vpc_configuration'] = data
+            else:
+                self.cache['vpc_configuration'] = None
+        return self.cache['vpc_configuration']
+
 
 # ----------------------------------------
 # Helpers
@@ -1254,9 +1278,12 @@ class TaskDefinition(TagsMixin, TaskDefinitionFARGATEMixin, SecretsMixin, Model)
         if 'volumes' in data:
             for volume in data['volumes']:
                 if 'efsVolumeConfiguration' in volume:
-                    volume['efsVolumeConfiguration']['FileSystem'] = EFSFileSystem.objects.get(
-                        volume['efsVolumeConfiguration']['fileSystemId']
-                    )
+                    try:
+                        volume['efsVolumeConfiguration']['FileSystem'] = EFSFileSystem.objects.get(
+                            volume['efsVolumeConfiguration']['fileSystemId']
+                        )
+                    except EFSFileSystem.DoesNotExist:
+                        volume['efsVolumeConfiguration']['FileSystem'] = "DOES NOT EXIST"
         return data
 
     def render_for_diff(self):
@@ -1390,7 +1417,7 @@ class ContainerDefinition(SecretsMixin, LazyAttributeMixin):
         return c
 
 
-class Task(TagsMixin, Model):
+class Task(TagsMixin, VPCConfigurationMixin, Model):
     """
     Tasks are TaskDefinitions with additional on how to run them as tasks.  Tasks can also be scheduled using Cloudwatch
     Events Rules.
@@ -1465,6 +1492,10 @@ class Task(TagsMixin, Model):
     def name(self):
         return self.pk
 
+    @property
+    def availability_zone(self):
+        return self.data['availabilityZone']
+
     @property
     def arn(self):
         return self.task_definition.arn
@@ -1802,7 +1833,7 @@ class Cluster(TagsMixin, SSHMixin, Model):
             )
 
 
-class Service(TagsMixin, DockerMixin, SecretsMixin, Model):
+class Service(TagsMixin, DockerMixin, SecretsMixin, VPCConfigurationMixin, Model):
 
     config_section = 'services'
 
@@ -1992,6 +2023,10 @@ class Service(TagsMixin, DockerMixin, SecretsMixin, Model):
     def status(self):
         return self.data.get('status', 'UNKNOWN')
 
+    @property
+    def exec_enabled(self):
+        return self.data.get('enableExecuteCommand', False)
+
     @property
     def events(self):
         return self.data.get('events', [])
@@ -2093,6 +2128,7 @@ class Service(TagsMixin, DockerMixin, SecretsMixin, Model):
         data = {}
         data['service'] = self.data['serviceName']
         data['cluster'] = self.data['cluster']
+        data['enableExecuteCommand'] = self.data['enableExecuteCommand']
         # Purposely not setting desiredCount here -- we may be scaled up, so we shouldn't be scaling back to whatever
         # deployfish.yml says lest we underprovision the service inadvertently
         data['taskDefinition'] = self.data['taskDefinition']
